
# q-expansion of newform 1710.2.p.d, downloaded from the LMFDB on 13 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1710
weight = 2
poly_data = [16, 0, 0, 0, 19120, 0, 0, 0, 78648, 0, 0, 0, 6416, 0, 0, 0, 153, 0, 0, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-599186688, 0, 0, 0, -1515721480, 0, 0, 0, -115242314, 0, 0, 0, -2625903, 0, 0, 0, -16765, 0, 0, 0], 174141704], [[0, 12328816792, 0, 0, 0, 63121710948, 0, 0, 0, 5168924442, 0, 0, 0, 123405389, 0, 0, 0, 806911, 0, 0], 2089700448], [[0, -10577293948, 0, 0, 0, -47719026672, 0, 0, 0, -3887923677, 0, 0, 0, -92597906, 0, 0, 0, -604825, 0, 0], 522425112], [[0, 0, 1096207364, 0, 0, 0, 4261561356, 0, 0, 0, 347394797, 0, 0, 0, 8282406, 0, 0, 0, 54129, 0], 31662128], [[-7006091376, 0, 216220477192, 0, -61610737104, 0, 933673009644, 0, -5124003060, 0, 76223127354, 0, -123229932, 0, 1818129965, 0, -808344, 0, 11884471, 0], 4179400896], [[-7006091376, 0, -216220477192, 0, -61610737104, 0, -933673009644, 0, -5124003060, 0, -76223127354, 0, -123229932, 0, -1818129965, 0, -808344, 0, -11884471, 0], 4179400896], [[-6281901056, 0, 240878110776, 0, -46444027032, 0, 1059916431540, 0, -3830938056, 0, 86560976238, 0, -92070010, 0, 2064940743, 0, -604298, 0, 13498293, 0], 4179400896], [[-7190240256, 64444570240, -248442762312, 0, -18188657760, 137351806272, -1002348912780, 0, -1382907768, 11011628496, -81728941602, 0, -31510836, 260775248, -1948517589, 0, -201180, 1699264, -12734103, 0], 4179400896], [[-6281901056, 0, -240878110776, 0, -46444027032, 0, -1059916431540, 0, -3830938056, 0, -86560976238, 0, -92070010, 0, -2064940743, 0, -604298, 0, -13498293, 0], 4179400896], [[-7190240256, -64444570240, -248442762312, 0, -18188657760, -137351806272, -1002348912780, 0, -1382907768, -11011628496, -81728941602, 0, -31510836, -260775248, -1948517589, 0, -201180, -1699264, -12734103, 0], 4179400896], [[0, 0, 0, -850240722328, 0, 0, 0, -3558464452956, 0, 0, 0, -290369158398, 0, 0, 0, -6924865889, 0, 0, 0, -45261895], 4179400896], [[0, 13651993928, 0, -423306773744, 0, 40901095068, 0, -1727640346328, 0, 3327761602, 0, -140922857856, 0, 79345865, 0, -3360431092, 0, 518651, 0, -21963356], 1393133632], [[0, 13651993928, 0, 423306773744, 0, 40901095068, 0, 1727640346328, 0, 3327761602, 0, 140922857856, 0, 79345865, 0, 3360431092, 0, 518651, 0, 21963356], 1393133632], [[0, -12258860296, 0, 471539897760, 0, -40901095068, 0, 1915149045992, 0, -3327761602, 0, 156208228924, 0, -79345865, 0, 3724856956, 0, -518651, 0, 24345032], 1393133632], [[0, -12258860296, 0, -471539897760, 0, -40901095068, 0, -1915149045992, 0, -3327761602, 0, -156208228924, 0, -79345865, 0, -3724856956, 0, -518651, 0, -24345032], 1393133632], [[11065189808, -42309175792, 0, -1459603333880, 136345642968, -190876106688, 0, -6057012474372, 11136819804, -15551694708, 0, -494177340558, 264708058, -370391624, 0, -11784791035, 1726694, -2419300, 0, -77025497], 4179400896], [[0, -42309175792, -379366025296, -1459603333880, 0, -190876106688, -1748182870776, -6057012474372, 0, -15551694708, -142817533980, -494177340558, 0, -370391624, -3406995518, -11784791035, 0, -2419300, -22270858, -77025497], 4179400896], [[7190240256, 0, 248442762312, 2227441426544, 18188657760, 0, 1002348912780, 8934778735776, 1382907768, 0, 81728941602, 728609156748, 31510836, 0, 1948517589, 17372793436, 201180, 0, 12734103, 113542400], 4179400896], [[0, 0, 0, 1459603333880, 0, 0, 0, 6057012474372, 0, 0, 0, 494177340558, 0, 0, 0, 11784791035, 0, 0, 0, 77025497], 2089700448]]

hecke_ring_character_values = [[191, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1027, [0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1351, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0, 0, 1], [0, 0, 0, -1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1], [0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1], [-2, 0, 0, 0, -2, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, 0, 0, 0, -1, 0, -1, 1, 1, 1, 0, 0, -1, 1], [0, 0, 0, -1, 0, 0, 0, 0, -1, 0, 0, 0, -1, 1, -1, -1, 0, 0, -1, 1], [0, 0, 0, -1, 0, 0, 0, 0, -1, 0, 1, 0, 2, 2, -1, -1, 0, 0, 0, 0], [0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, -1, -1, 0, -1, 0, 0, 0, 0, -1], [3, 0, 0, 0, 3, 1, 1, -1, 0, 1, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0], [0, -2, 0, 0, 0, -2, 1, -2, 1, -1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, -2, -2, 2, 0, 0, 0, 0, -2, 0], [0, 0, 1, 1, 0, 0, 0, 0, 0, 0, -1, 1, -1, 0, 1, 0, 0, 0, -1, 1], [2, 0, 0, 0, 0, 1, 1, -1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, -2, -2, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -2, 0, 0, 0, 0], [-1, 0, 0, 0, -1, 0, -2, 0, -1, -2, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, -1, 1], [6, 0, 0, 0, 6, 0, -1, 0, -1, -1, -1, 0, 0, 0, 0, 0, -1, 1, 0, 0], [0, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0, -5, 2, 1, -2, 1, 0, 0, 0, 0], [0, 0, 2, 3, 0, 0, 0, 0, 1, 0, -1, 0, -1, -1, 3, 3, 0, 0, 0, 0], [0, 0, 0, 1, 0, 2, 2, -1, 0, -1, 0, 0, 0, 0, 0, 0, -2, 0, 0, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -6, -2, 2, -3, 3, 0, 0, 0, 2], [0, 0, -6, -2, 0, 0, 0, 0, -1, 0, 1, 0, 1, 1, -3, -3, 0, 0, 0, 0], [0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 1, 0, 1, 1, -1, 1, 0, 0, 1, -2], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, -3, 3, -1, 1, 0, 0, 0, 0], [0, 0, -10, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, -1, -2, -2, 0, 0, 0, 0], [0, -1, 0, 1, 0, 1, 1, -1, 0, -1, 0, 0, 0, 0, 0, 0, -2, 0, 0, -1], [4, -2, 0, -1, -4, -1, -2, -1, 1, 2, 1, 0, 0, 0, 0, 0, 1, 1, 0, 1], [0, -2, 0, 0, 2, -3, 3, 1, 2, -1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 2, 0, -1, 0, -2, 2, 1, -2, -1, -2, 0, 0, 0, 0, 0, 0, 2, 0, 1], [0, 0, 2, -1, 0, 0, 0, 0, 1, 0, 0, -2, -2, 2, -2, -2, 0, 0, 1, 1], [2, 2, 0, 1, -2, 3, -2, 3, -1, 2, -1, 0, 0, 0, 0, 0, -1, -1, 0, -1], [5, 0, 0, 0, 5, -1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 1, -1, 0, 0], [0, 0, -4, -2, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, 4, 4, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, 2, 2, -2, 0, 0, 0, 2], [0, 0, 5, -2, 0, 0, 0, 0, 0, 0, -1, 5, 1, 0, -1, 0, 0, 0, -1, -2], [0, 0, 0, -1, 0, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1], [-2, -1, 0, 0, 0, 4, 4, -3, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, 2, 3, -3, 1, -1, 0, 0, -2, 1], [2, 0, 0, -2, -2, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 0, 2], [0, 0, 0, 1, -4, -1, 1, 3, 0, -3, 0, 0, 0, 0, 0, 0, 0, -2, 0, -1], [0, 0, 2, -1, 0, 0, 0, 0, 2, 0, 0, -2, -2, 0, -2, 0, 0, 0, 2, 1], [0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, 14, 0, 0, -1, 1, 0, 0, -2, 0], [0, 0, -2, -4, 0, 0, 0, 0, -3, 0, 3, 0, 1, 1, -3, -3, 0, 0, 0, 0], [0, 2, 0, -1, 2, 0, 0, 2, -2, -2, -2, 0, 0, 0, 0, 0, 0, 2, 0, 1], [2, 0, 0, 0, 2, -4, 3, 4, 3, 3, 3, 0, 0, 0, 0, 0, 1, -1, 0, 0], [0, 1, 0, -1, 2, 6, -6, 1, -1, -1, -1, 0, 0, 0, 0, 0, 0, 2, 0, 1], [0, 0, 0, 1, 0, 0, 0, 0, 4, 0, 0, 0, 2, -2, 2, 2, 0, 0, 4, -1], [-4, 1, 0, 1, 0, -3, -3, 3, 0, 3, 0, 0, 0, 0, 0, 0, -2, 0, 0, -1], [0, 0, 4, -2, 0, 0, 0, 0, 0, 0, 0, 0, -1, -1, 3, 3, 0, 0, 0, 0], [-4, 0, 0, 0, -4, -1, 0, 1, -1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -4, 1, 0, 0, 0, 0, 0, 0, -1, -4, -3, -3, 3, -3, 0, 0, -1, 1], [-4, 0, 0, 1, 0, 5, 5, -3, 0, -3, 0, 0, 0, 0, 0, 0, -2, 0, 0, -1], [-2, -2, 0, 3, 2, -7, 0, -7, 1, 0, 1, 0, 0, 0, 0, 0, -3, -3, 0, -3], [0, 0, -5, -1, 0, 0, 0, 0, -2, 0, 0, 5, -3, 0, -3, 0, 0, 0, -2, 1], [1, 0, 0, 0, 1, -3, 1, 3, -3, 1, -3, 0, 0, 0, 0, 0, -1, 1, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 2, 2, -2, -2, 2, 0, 0, 2, 0], [0, 0, -8, 0, 0, 0, 0, 0, 2, 0, -2, 0, 2, 2, 6, 6, 0, 0, 0, 0], [-2, 1, 0, 0, 0, -3, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [5, 0, 0, 0, 5, 6, -4, -6, -1, -4, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 2, -2, 0, 0, 0, 0, -2, 0, 2, 0, 6, 6, -4, -4, 0, 0, 0, 0], [0, 0, -8, 2, 0, 0, 0, 0, 2, 0, 0, 8, -2, -4, -2, 4, 0, 0, 2, -2], [0, 0, 2, -3, 0, 0, 0, 0, -3, 0, 3, 0, 1, 1, -3, -3, 0, 0, 0, 0], [-4, 0, 0, 1, 4, -5, -4, -5, 0, 4, 0, 0, 0, 0, 0, 0, -1, -1, 0, -1], [0, 2, 0, 1, 18, -1, 1, -1, -2, 1, -2, 0, 0, 0, 0, 0, 0, -2, 0, -1], [-6, 0, 0, 0, -6, 6, -5, -6, -3, -5, -3, 0, 0, 0, 0, 0, -1, 1, 0, 0], [0, -5, 0, 3, 2, -1, 1, -2, 5, 2, 5, 0, 0, 0, 0, 0, 0, -6, 0, -3], [4, -4, 0, 0, -4, -2, -3, -2, 2, 3, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, -4, 3, -3, 2, -2, 0, 0, -2, -1], [0, 0, -6, 0, 0, 0, 0, 0, 0, 0, 0, -6, 0, -4, 0, -4, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 16, 0, 0, 0, 0, 0, 0, 2, -4], [0, 0, 0, 1, 4, -1, 1, -8, 0, 8, 0, 0, 0, 0, 0, 0, 0, -2, 0, -1], [6, 2, 0, -3, -6, -1, -2, -1, -1, 2, -1, 0, 0, 0, 0, 0, 3, 3, 0, 3], [0, 0, -3, 1, 0, 0, 0, 0, 0, 0, 0, 3, -1, 2, -1, -2, 0, 0, 0, -1], [0, 0, 6, 1, 0, 0, 0, 0, 0, 0, -2, 6, -4, 0, 4, 0, 0, 0, -2, 1], [0, 3, 0, 0, -4, 6, -6, 2, -3, -2, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 2, 0, 0, 0, 0, 3, 0, 0, 0, -1, 1, -1, -1, 0, 0, 3, -2], [0, 0, -4, 2, 0, 0, 0, 0, 4, 0, 0, 4, 6, -2, 6, 2, 0, 0, 4, -2], [0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, 10, -1, 1, -7, 7, 0, 0, -2, -1], [0, 0, -2, 1, 0, 0, 0, 0, 0, 0, 1, -2, 3, 3, -3, 3, 0, 0, 1, 1], [14, 0, 0, 0, 14, -2, -1, 2, -2, -1, -2, 0, 0, 0, 0, 0, -1, 1, 0, 0], [0, 0, 9, -2, 0, 0, 0, 0, 0, 0, 2, 9, -2, 1, 2, 1, 0, 0, 2, -2], [-13, 0, 0, -4, 13, 4, -6, 4, 0, 6, 0, 0, 0, 0, 0, 0, 4, 4, 0, 4], [4, -2, 0, 2, 0, -3, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, 0, 0, -2], [-10, 0, 0, 0, -10, -3, 0, 3, 2, 0, 2, 0, 0, 0, 0, 0, -2, 2, 0, 0], [4, -2, 0, 1, -4, 3, 6, 3, 1, -6, 1, 0, 0, 0, 0, 0, -1, -1, 0, -1], [0, 5, 0, -2, 2, 1, -1, 2, -5, -2, -5, 0, 0, 0, 0, 0, 0, 4, 0, 2], [0, 0, 14, -2, 0, 0, 0, 0, -1, 0, 1, 0, -3, -3, -2, -2, 0, 0, 0, 0], [-8, 1, 0, -1, 0, -1, -1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1], [0, 0, 0, 2, -4, 6, -6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, 0, -2], [-10, 0, 0, 0, -10, -4, 5, 4, 0, 5, 0, 0, 0, 0, 0, 0, 2, -2, 0, 0], [0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 3, 0, -1, 5, 1, 5, 0, 0, 3, 1], [0, 0, 7, 0, 0, 0, 0, 0, 2, 0, 0, -7, -3, -8, -3, 8, 0, 0, 2, 0], [0, 0, 0, 0, 0, 0, 0, 0, -2, 0, -2, 8, 0, 0, 4, -4, 0, 0, -4, -4], [-18, 2, 0, 1, 0, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, -2, 0, 0, -1], [0, 0, -16, -2, 0, 0, 0, 0, 2, 0, -2, 0, 0, 0, 4, 4, 0, 0, 0, 0], [-4, 0, 0, -4, 4, 4, 3, 4, 0, -3, 0, 0, 0, 0, 0, 0, 4, 4, 0, 4], [0, 0, 0, 0, 0, 0, 0, 0, -3, 0, -3, 10, -7, 7, 3, -3, 0, 0, -6, 6], [0, 0, 5, 2, 0, 0, 0, 0, 0, 0, -2, 5, 2, -3, -2, -3, 0, 0, -2, 2], [8, 0, 0, -1, 0, -1, -1, 7, 0, 7, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1], [-1, -4, 0, -4, 1, -2, 0, -2, 2, 0, 2, 0, 0, 0, 0, 0, 4, 4, 0, 4], [4, -6, 0, 1, -4, 3, 4, 3, 3, -4, 3, 0, 0, 0, 0, 0, -1, -1, 0, -1], [0, 0, 0, 0, 0, 0, 1, 0, -1, 1, -1, 0, 0, 0, 0, 0, -1, 1, 0, 0], [0, 0, -6, 2, 0, 0, 0, 0, 0, 0, -4, -6, -4, 4, 4, 4, 0, 0, -4, 2], [0, 0, -6, 2, 0, 0, 0, 0, 2, 0, 0, 6, 6, -2, 6, 2, 0, 0, 2, -2], [0, 0, 26, -2, 0, 0, 0, 0, -1, 0, 1, 0, -1, -1, -2, -2, 0, 0, 0, 0], [8, 0, 0, 0, 8, 2, 3, -2, 5, 3, 5, 0, 0, 0, 0, 0, -1, 1, 0, 0], [-20, 4, 0, 1, 20, -5, -2, -5, -2, 2, -2, 0, 0, 0, 0, 0, -1, -1, 0, -1], [0, -6, 0, 2, -14, -5, 5, 1, 6, -1, 6, 0, 0, 0, 0, 0, 0, -4, 0, -2], [4, -2, 0, 2, 0, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, -4, 0, 0, -2], [0, 0, -3, 4, 0, 0, 0, 0, 2, 0, 0, 3, 3, 2, 3, -2, 0, 0, 2, -4], [-9, 0, 0, 0, -9, 3, -7, -3, -1, -7, -1, 0, 0, 0, 0, 0, -1, 1, 0, 0], [-2, 0, 0, 2, 2, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, 0, -2], [18, 0, 0, 0, 18, 1, 2, -1, 2, 2, 2, 0, 0, 0, 0, 0, 2, -2, 0, 0], [0, 0, 1, 6, 0, 0, 0, 0, 0, 0, -5, 1, -1, 2, 1, 2, 0, 0, -5, 6], [0, 0, 12, -5, 0, 0, 0, 0, -1, 0, 0, -12, -4, -2, -4, 2, 0, 0, -1, 5], [0, 0, 0, 0, 0, 0, 0, 0, -3, 0, -3, -10, -9, 9, -1, 1, 0, 0, -6, 1], [0, 0, -6, 2, 0, 0, 0, 0, 0, 0, 0, 0, -10, -10, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, -10, 3, -3, -3, 3, 0, 0, -2, -4], [0, 0, 0, -1, 0, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1], [-4, 6, 0, -2, 0, 6, 6, 5, 0, 5, 0, 0, 0, 0, 0, 0, 4, 0, 0, 2], [0, 0, 0, -2, 18, -1, 1, -1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 4, 0, 2], [0, -5, 0, 3, 10, -5, 5, -2, 5, 2, 5, 0, 0, 0, 0, 0, 0, -6, 0, -3], [8, 4, 0, 0, -8, 4, -1, 4, -2, 1, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [12, 0, 0, 0, 12, 0, -3, 0, -5, -3, -5, 0, 0, 0, 0, 0, -3, 3, 0, 0], [0, -8, 0, 3, -2, -6, 6, -4, 8, 4, 8, 0, 0, 0, 0, 0, 0, -6, 0, -3], [0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, -4, -4, 4, -4, 4, 0, 0, -2, -6], [0, 0, 8, -3, 0, 0, 0, 0, -3, 0, 0, -8, -1, -1, -1, 1, 0, 0, -3, 3], [6, 2, 0, -3, -6, 3, 6, 3, -1, -6, -1, 0, 0, 0, 0, 0, 3, 3, 0, 3], [-2, 2, 0, -1, 0, 1, 1, 3, 0, 3, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1], [0, 2, 0, -2, -10, 4, -4, 2, -2, -2, -2, 0, 0, 0, 0, 0, 0, 4, 0, 2], [0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 6, 8, -8, 6, -6, 0, 0, 4, 0], [0, 0, -8, 4, 0, 0, 0, 0, 0, 0, 0, 0, -4, -4, 4, 4, 0, 0, 0, 0], [0, 0, 6, 4, 0, 0, 0, 0, 2, 0, -2, 0, 8, 8, 4, 4, 0, 0, 0, 0], [0, -6, 0, 3, 14, -1, 1, 1, 6, -1, 6, 0, 0, 0, 0, 0, 0, -6, 0, -3], [0, 0, -14, 1, 0, 0, 0, 0, -2, 0, 0, 14, 6, 6, 6, -6, 0, 0, -2, -1], [-20, -4, 0, -1, 0, -3, -3, 4, 0, 4, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1], [-14, 0, 0, 0, -14, -5, 4, 5, 2, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -6, 4, 0, 0, 0, 0, -3, 0, 3, 0, 1, 1, 1, 1, 0, 0, 0, 0], [0, 0, -16, 4, 0, 0, 0, 0, 0, 0, -1, -16, 3, 3, -3, 3, 0, 0, -1, 4], [0, 0, -6, 0, 0, 0, 0, 0, 0, 0, -2, -6, 4, -8, -4, -8, 0, 0, -2, 0], [14, 0, 0, 0, 14, 4, 7, -4, -1, 7, -1, 0, 0, 0, 0, 0, 3, -3, 0, 0], [0, 0, 4, 0, 0, 0, 0, 0, -4, 0, 4, 0, 1, 1, -3, -3, 0, 0, 0, 0], [0, -2, 0, -1, 16, 3, -3, -1, 2, 1, 2, 0, 0, 0, 0, 0, 0, 2, 0, 1], [0, 0, 0, 0, 0, 0, 0, 0, -3, 0, -3, -4, -6, 6, -8, 8, 0, 0, -6, 0], [0, 0, 0, -3, 0, 0, 0, 0, -4, 0, 4, 0, 12, 12, -3, -3, 0, 0, 0, 0], [-10, -4, 0, -1, 0, -3, -3, 1, 0, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1], [11, 0, 0, 0, 11, -7, 3, 7, 4, 3, 4, 0, 0, 0, 0, 0, 1, -1, 0, 0], [0, 0, 12, 2, 0, 0, 0, 0, 3, 0, -3, 0, -2, -2, -4, -4, 0, 0, 0, 0], [0, 0, 0, 2, 0, 0, 0, 0, 4, 0, -4, 0, 6, 6, 4, 4, 0, 0, 0, 0], [0, 0, -12, -4, 0, 0, 0, 0, 0, 0, 0, 12, 4, 4, 4, -4, 0, 0, 0, 4], [0, 2, 0, 2, 8, -3, 3, 1, -2, -1, -2, 0, 0, 0, 0, 0, 0, -4, 0, -2], [0, 6, 0, -1, 6, 9, -9, -1, -6, 1, -6, 0, 0, 0, 0, 0, 0, 2, 0, 1], [-9, -2, 0, -2, 9, -4, 2, -4, 1, -2, 1, 0, 0, 0, 0, 0, 2, 2, 0, 2], [0, 0, 4, -7, 0, 0, 0, 0, -9, 0, 0, -4, -1, 7, -1, -7, 0, 0, -9, 7], [0, 4, 0, -3, 0, 7, 2, 7, -2, -2, -2, 0, 0, 0, 0, 0, 3, 3, 0, 3], [0, 0, 0, 0, 0, 0, 0, 0, -4, 0, -4, 2, -8, 8, 6, -6, 0, 0, -8, 4], [10, -12, 0, 6, -10, -6, -3, -6, 6, 3, 6, 0, 0, 0, 0, 0, -6, -6, 0, -6], [0, 0, 5, -2, 0, 0, 0, 0, 1, 0, 0, -5, -8, 1, -8, -1, 0, 0, 1, 2], [0, 0, -10, -2, 0, 0, 0, 0, 0, 0, 0, 0, -4, -4, 10, 10, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -12, 2, -2, 2, -2, 0, 0, 0, -2], [0, 0, -14, -1, 0, 0, 0, 0, -5, 0, 0, 14, -7, -1, -7, 1, 0, 0, -5, 1], [-2, -10, 0, 5, 2, -7, 2, -7, 5, -2, 5, 0, 0, 0, 0, 0, -5, -5, 0, -5], [0, 0, -8, -5, 0, 0, 0, 0, 0, 0, -4, -8, -2, 6, 2, 6, 0, 0, -4, -5], [24, 0, 0, 0, 24, -2, -3, 2, -2, -3, -2, 0, 0, 0, 0, 0, -2, 2, 0, 0], [0, 0, 11, 4, 0, 0, 0, 0, 0, 0, -7, 11, -7, 0, 7, 0, 0, 0, -7, 4], [0, 0, 8, 1, 0, 0, 0, 0, 1, 0, 0, -8, -2, 6, -2, -6, 0, 0, 1, -1], [2, 9, 0, -3, 0, 1, 1, 4, 0, 4, 0, 0, 0, 0, 0, 0, 6, 0, 0, 3], [-23, 0, 0, 0, -23, -6, 2, 6, 1, 2, 1, 0, 0, 0, 0, 0, 4, -4, 0, 0], [0, 0, 20, -5, 0, 0, 0, 0, 0, 0, 1, 20, 2, -8, -2, -8, 0, 0, 1, -5], [0, -2, 0, 2, -10, -2, 2, -6, 2, 6, 2, 0, 0, 0, 0, 0, 0, -4, 0, -2], [10, -10, 0, 0, 0, -1, -1, -1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [4, 0, 0, 2, 0, 2, 2, -7, 0, -7, 0, 0, 0, 0, 0, 0, -4, 0, 0, -2], [0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 4, 6, -4, 4, -1, 1, 0, 0, 8, 4], [0, 8, 0, -2, -10, 2, -2, 2, -8, -2, -8, 0, 0, 0, 0, 0, 0, 4, 0, 2], [-8, -4, 0, 0, 8, 2, -7, 2, 2, 7, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -5, 1, 0, 0, 0, 0, -5, 0, 0, 5, -10, -1, -10, 1, 0, 0, -5, -1], [0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 4, -1, 1, -6, 6, 0, 0, 4, 1], [0, 0, -10, -4, 0, 0, 0, 0, 2, 0, -2, 0, 6, 6, -4, -4, 0, 0, 0, 0], [4, 0, 0, 0, 4, 9, 2, -9, -3, 2, -3, 0, 0, 0, 0, 0, -4, 4, 0, 0], [0, 10, 0, -1, -4, 9, -9, 4, -10, -4, -10, 0, 0, 0, 0, 0, 0, 2, 0, 1], [0, 0, -4, 1, 0, 0, 0, 0, -1, 0, 1, 0, 0, 0, 13, 13, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, -12, 12, -12, 0, 0, 0, 0, 4, -8], [0, 0, 10, -4, 0, 0, 0, 0, 0, 0, 2, 10, 6, -8, -6, -8, 0, 0, 2, -4], [2, 1, 0, 3, 0, -2, -2, -5, 0, -5, 0, 0, 0, 0, 0, 0, -6, 0, 0, -3], [0, 0, 0, 0, 0, 0, 0, 0, -3, 0, -3, -6, -3, 3, 7, -7, 0, 0, -6, 5], [6, 0, 0, 0, 6, 8, 5, -8, 4, 5, 4, 0, 0, 0, 0, 0, -3, 3, 0, 0], [0, 0, 2, 7, 0, 0, 0, 0, 2, 0, 0, -2, 4, -8, 4, 8, 0, 0, 2, -7], [0, 0, 10, 1, 0, 0, 0, 0, 1, 0, 0, -10, -5, -1, -5, 1, 0, 0, 1, -1], [-12, 6, 0, -3, 12, -1, 4, -1, -3, -4, -3, 0, 0, 0, 0, 0, 3, 3, 0, 3], [0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, -14, 0, 0, 6, -6, 0, 0, 4, 4], [10, 0, 0, -4, 0, 4, 4, 4, 0, 4, 0, 0, 0, 0, 0, 0, 8, 0, 0, 4], [2, 0, 0, 0, 2, 2, -5, -2, 5, -5, 5, 0, 0, 0, 0, 0, -1, 1, 0, 0], [-10, 0, 0, -5, 10, 5, -10, 5, 0, 10, 0, 0, 0, 0, 0, 0, 5, 5, 0, 5], [4, 0, 0, 0, 4, -7, -2, 7, -3, -2, -3, 0, 0, 0, 0, 0, -6, 6, 0, 0], [0, 0, -4, -5, 0, 0, 0, 0, 0, 0, 5, -4, 7, -11, -7, -11, 0, 0, 5, -5], [0, 0, 12, 5, 0, 0, 0, 0, 1, 0, 0, -12, 8, -10, 8, 10, 0, 0, 1, -5], [0, 0, 4, 3, 0, 0, 0, 0, -3, 0, 3, 0, 0, 0, 3, 3, 0, 0, 0, 0], [0, 0, -8, 3, 0, 0, 0, 0, 0, 0, -10, -8, -6, 2, 6, 2, 0, 0, -10, 3], [0, 3, 0, 5, 16, -3, 3, 1, -3, -1, -3, 0, 0, 0, 0, 0, 0, -10, 0, -5], [30, 4, 0, 2, -30, -3, 4, -3, -2, -4, -2, 0, 0, 0, 0, 0, -2, -2, 0, -2], [0, 8, 0, -3, 20, 10, -10, -4, -8, 4, -8, 0, 0, 0, 0, 0, 0, 6, 0, 3], [0, 0, 0, 0, 0, 0, 0, 0, -3, 0, -3, -10, -1, 1, 3, -3, 0, 0, -6, 0], [0, -2, 0, -1, 6, 9, -9, 1, 2, -1, 2, 0, 0, 0, 0, 0, 0, 2, 0, 1], [0, 0, 12, -3, 0, 0, 0, 0, 2, 0, 0, -12, -12, -6, -12, 6, 0, 0, 2, 3], [9, 4, 0, -2, -9, 2, -6, 2, -2, 6, -2, 0, 0, 0, 0, 0, 2, 2, 0, 2], [12, -14, 0, 6, 0, -2, -2, -11, 0, -11, 0, 0, 0, 0, 0, 0, -12, 0, 0, -6], [12, 0, 0, 0, 12, 3, -4, -3, -2, -4, -2, 0, 0, 0, 0, 0, 4, -4, 0, 0], [0, 0, 10, -6, 0, 0, 0, 0, -3, 0, 3, 0, -1, -1, 5, 5, 0, 0, 0, 0], [0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 8, 6, -2, 8, 2, 8, 0, 0, 8, 0], [0, 0, 14, 3, 0, 0, 0, 0, -4, 0, 0, -14, -6, 4, -6, -4, 0, 0, -4, -3], [-10, 4, 0, 4, 10, 2, -1, 2, -2, 1, -2, 0, 0, 0, 0, 0, -4, -4, 0, -4], [0, 0, 3, 3, 0, 0, 0, 0, -4, 0, 0, -3, 9, -10, 9, 10, 0, 0, -4, -3], [0, 0, 0, -10, 0, 0, 0, 0, 4, 0, -4, 0, 2, 2, -2, -2, 0, 0, 0, 0], [2, 0, 0, 0, 2, 10, -11, -10, -6, -11, -6, 0, 0, 0, 0, 0, -6, 6, 0, 0], [0, 0, -20, -4, 0, 0, 0, 0, -7, 0, 0, 20, 1, 7, 1, -7, 0, 0, -7, 4], [0, 0, -18, -1, 0, 0, 0, 0, 0, 0, 1, -18, 2, 6, -2, 6, 0, 0, 1, -1], [0, 0, -5, 2, 0, 0, 0, 0, 0, 0, 6, -5, -2, -3, 2, -3, 0, 0, 6, 2], [8, 0, 0, 0, 8, 3, -2, -3, 0, -2, 0, 0, 0, 0, 0, 0, -6, 6, 0, 0], [0, 0, 4, -4, 0, 0, 0, 0, -2, 0, 2, 0, 2, 2, 6, 6, 0, 0, 0, 0], [0, -2, 0, -1, 2, -13, 13, 9, 2, -9, 2, 0, 0, 0, 0, 0, 0, 2, 0, 1], [0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 14, -4, 4, -8, 8, 0, 0, 4, 0], [0, 0, 20, 0, 0, 0, 0, 0, 0, 0, 4, 20, 4, 0, -4, 0, 0, 0, 4, 0], [0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 5, 5, 6, 6, 0, 0, 0, 0], [-28, -1, 0, 3, 0, 3, 3, 7, 0, 7, 0, 0, 0, 0, 0, 0, -6, 0, 0, -3], [28, 0, 0, 0, 28, -4, -1, 4, -1, -1, -1, 0, 0, 0, 0, 0, -5, 5, 0, 0], [0, 0, 22, 0, 0, 0, 0, 0, 0, 0, 2, 22, 2, 6, -2, 6, 0, 0, 2, 0], [0, 0, -18, -3, 0, 0, 0, 0, -5, 0, 0, 18, 1, -1, 1, 1, 0, 0, -5, 3], [0, 0, -11, 6, 0, 0, 0, 0, 0, 0, 0, 11, 3, -2, 3, 2, 0, 0, 0, -6], [5, 0, 0, 0, 5, 9, -3, -9, -5, -3, -5, 0, 0, 0, 0, 0, 3, -3, 0, 0], [-10, 12, 0, -4, 10, 7, -8, 7, -6, 8, -6, 0, 0, 0, 0, 0, 4, 4, 0, 4], [0, 0, 0, -4, 18, -10, 10, 6, 0, -6, 0, 0, 0, 0, 0, 0, 0, 8, 0, 4], [0, 0, 0, 0, 0, 7, 0, -7, -2, 0, -2, 0, 0, 0, 0, 0, 6, -6, 0, 0], [0, -3, 0, -1, 32, 1, -1, -5, 3, 5, 3, 0, 0, 0, 0, 0, 0, 2, 0, 1], [0, 0, -14, 6, 0, 0, 0, 0, 6, 0, 0, 14, 4, -10, 4, 10, 0, 0, 6, -6], [0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 4, 8, 8, -8, 6, -6, 0, 0, 8, -8], [10, 0, 0, 4, 0, 9, 9, -9, 0, -9, 0, 0, 0, 0, 0, 0, -8, 0, 0, -4], [-14, 0, 0, 0, -14, -1, 4, 1, 2, 4, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 20, -3, 0, 0, 0, 0, 0, 0, 3, 20, 2, 0, -2, 0, 0, 0, 3, -3], [0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 4, -2, 0, 0, 0, 0, 0, 0, 8, -6], [0, -3, 0, 7, -10, -4, 4, -1, 3, 1, 3, 0, 0, 0, 0, 0, 0, -14, 0, -7], [10, 8, 0, -2, -10, -4, 1, -4, -4, -1, -4, 0, 0, 0, 0, 0, 2, 2, 0, 2], [0, 0, 5, -3, 0, 0, 0, 0, -3, 0, 0, -5, 10, 7, 10, -7, 0, 0, -3, 3], [0, 0, -8, 2, 0, 0, 0, 0, 0, 0, 0, -8, -2, -8, 2, -8, 0, 0, 0, 2], [32, 0, 0, 0, 32, 5, 8, -5, -1, 8, -1, 0, 0, 0, 0, 0, 2, -2, 0, 0], [-10, -2, 0, 5, 10, 5, 14, 5, 1, -14, 1, 0, 0, 0, 0, 0, -5, -5, 0, -5], [-2, -4, 0, 2, 0, 2, 2, 6, 0, 6, 0, 0, 0, 0, 0, 0, -4, 0, 0, -2], [0, -2, 0, -6, 0, 2, -7, 2, 1, 7, 1, 0, 0, 0, 0, 0, 6, 6, 0, 6], [0, 0, 14, -7, 0, 0, 0, 0, 0, 0, 12, 14, 12, -4, -12, -4, 0, 0, 12, -7], [-26, 0, 0, 0, -26, -6, 7, 6, 2, 7, 2, 0, 0, 0, 0, 0, 8, -8, 0, 0], [0, -5, 0, 0, -8, 8, -8, 0, 5, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0], [10, -10, 0, 3, 0, 2, 2, -10, 0, -10, 0, 0, 0, 0, 0, 0, -6, 0, 0, -3], [0, 0, 28, 2, 0, 0, 0, 0, 0, 0, 0, 0, -8, -8, -6, -6, 0, 0, 0, 0], [0, 0, 6, -10, 0, 0, 0, 0, -1, 0, 1, 0, 10, 10, 0, 0, 0, 0, 0, 0], [5, -2, 0, 6, -5, -14, 2, -14, 1, -2, 1, 0, 0, 0, 0, 0, -6, -6, 0, -6], [0, 0, 0, 0, 0, 0, 0, 0, 7, 0, 7, -2, -2, 2, 1, -1, 0, 0, 14, 4], [0, 0, -16, 12, 0, 0, 0, 0, 2, 0, -2, 0, -4, -4, 6, 6, 0, 0, 0, 0], [0, 8, 0, 4, 14, -2, 2, 2, -8, -2, -8, 0, 0, 0, 0, 0, 0, -8, 0, -4], [0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 12, -3, 3, -8, 8, 0, 0, 4, 1], [6, 16, 0, 1, -6, -3, 2, -3, -8, -2, -8, 0, 0, 0, 0, 0, -1, -1, 0, -1], [0, 0, 4, 2, 0, 0, 0, 0, 0, 0, 6, 4, -6, 6, 6, 6, 0, 0, 6, 2], [0, 0, -32, 1, 0, 0, 0, 0, 0, 0, -1, -32, -3, -1, 3, -1, 0, 0, -1, 1], [-10, 4, 0, -5, 0, -1, -1, 11, 0, 11, 0, 0, 0, 0, 0, 0, 10, 0, 0, 5], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, -12, 12, 6, -6, 0, 0, 0, 4], [18, 0, 0, 0, 18, -3, -6, 3, -4, -6, -4, 0, 0, 0, 0, 0, 2, -2, 0, 0], [0, 0, 8, -7, 0, 0, 0, 0, -1, 0, 0, -8, 10, 2, 10, -2, 0, 0, -1, 7], [0, 0, 20, 2, 0, 0, 0, 0, 4, 0, -4, 0, 6, 6, 0, 0, 0, 0, 0, 0], [7, 0, 0, 0, 7, -4, 4, 4, -3, 4, -3, 0, 0, 0, 0, 0, 4, -4, 0, 0], [0, -2, 0, -1, -16, 0, 0, 8, 2, -8, 2, 0, 0, 0, 0, 0, 0, 2, 0, 1], [0, 0, -10, -3, 0, 0, 0, 0, 1, 0, -1, 0, -5, -5, -1, -1, 0, 0, 0, 0], [-8, 0, 0, 0, -8, 5, 2, -5, 0, 2, 0, 0, 0, 0, 0, 0, -2, 2, 0, 0], [-16, 0, 0, -1, 16, -1, -4, -1, 0, 4, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1], [0, 0, -4, -7, 0, 0, 0, 0, 0, 0, 5, -4, 6, -8, -6, -8, 0, 0, 5, -7], [0, 0, 10, 3, 0, 0, 0, 0, 2, 0, 0, -10, -6, -12, -6, 12, 0, 0, 2, -3], [-12, -7, 0, 2, 0, -10, -10, -2, 0, -2, 0, 0, 0, 0, 0, 0, -4, 0, 0, -2], [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 8, 6, -6, 0, 0, 0, 0, 2, -2], [0, -10, 0, 1, 0, -1, -1, 5, 0, 5, 0, 0, 0, 0, 0, 0, -2, 0, 0, -1], [24, 2, 0, 0, -24, 4, 3, 4, -1, -3, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 12, -8, 0, 0, 0, 0, -5, 0, 0, -12, -7, 9, -7, -9, 0, 0, -5, 8], [11, -6, 0, 3, -11, -11, 11, -11, 3, -11, 3, 0, 0, 0, 0, 0, -3, -3, 0, -3], [26, 3, 0, -1, 0, 3, 3, -2, 0, -2, 0, 0, 0, 0, 0, 0, 2, 0, 0, 1], [-15, 0, 0, 0, -15, 6, 2, -6, 4, 2, 4, 0, 0, 0, 0, 0, 4, -4, 0, 0], [0, 0, -10, 4, 0, 0, 0, 0, -4, 0, 4, 0, 2, 2, -4, -4, 0, 0, 0, 0], [0, -2, 0, -3, -16, 5, -5, 11, 2, -11, 2, 0, 0, 0, 0, 0, 0, 6, 0, 3], [0, 0, 1, -1, 0, 0, 0, 0, 0, 0, -2, 1, -12, -7, 12, -7, 0, 0, -2, -1], [-4, 0, 0, 2, 0, 1, 1, -2, 0, -2, 0, 0, 0, 0, 0, 0, -4, 0, 0, -2], [14, -6, 0, 3, -14, -7, -4, -7, 3, 4, 3, 0, 0, 0, 0, 0, -3, -3, 0, -3], [0, 0, 0, 0, 0, 0, 0, 0, -4, 0, -4, 0, -9, 9, 1, -1, 0, 0, -8, 14], [0, 0, 1, -8, 0, 0, 0, 0, -3, 0, 0, -1, 4, -1, 4, 1, 0, 0, -3, 8], [0, 0, 0, 0, 0, 0, 0, 0, 5, 0, 5, 20, 13, -13, -4, 4, 0, 0, 10, -3], [0, -2, 0, -6, 8, 6, -6, 1, 2, -1, 2, 0, 0, 0, 0, 0, 0, 12, 0, 6], [0, 0, -4, 3, 0, 0, 0, 0, -3, 0, 0, 4, -8, 4, -8, -4, 0, 0, -3, -3], [-2, 0, 0, 0, -2, 9, 0, -9, 2, 0, 2, 0, 0, 0, 0, 0, 10, -10, 0, 0], [0, 0, -13, 1, 0, 0, 0, 0, 0, 0, 1, -13, 3, 0, -3, 0, 0, 0, 1, 1], [-3, -6, 0, 5, 3, 7, 5, 7, 3, -5, 3, 0, 0, 0, 0, 0, -5, -5, 0, -5], [41, 0, 0, 0, 41, -4, -2, 4, 2, -2, 2, 0, 0, 0, 0, 0, 4, -4, 0, 0], [0, 0, 38, 0, 0, 0, 0, 0, 2, 0, -2, 0, 0, 0, -6, -6, 0, 0, 0, 0], [0, 0, 0, 4, 40, -4, 4, -4, 0, 4, 0, 0, 0, 0, 0, 0, 0, -8, 0, -4]]
